==> mclust_2.1-5.tar.gz: mclust/data/diabetes.R <==
"diabetes" <- 
structure(.Data = list("class" = structure(.Data = c(2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 2, 1, 1, 2, 2, 2, 2, 1,
	2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3)
, class = "factor"
, levels = c("chemical", "normal", "overt")
)
, "glucose" = c(80., 97., 105., 90., 90., 86., 100., 85., 97., 97., 91., 87., 78., 90., 86.,
	80., 90., 99., 85., 90., 90., 88., 95., 90., 92., 74., 98., 100., 86.,
	98., 70., 99., 75., 90., 85., 99., 100., 78., 106., 98., 102., 90.,
	94., 80., 93., 86., 85., 96., 88., 87., 94., 93., 86., 86., 96., 86.,
	89., 83., 98., 100., 110., 88., 100., 80., 89., 91., 96., 95., 82.,
	84., 90., 100., 86., 93., 107., 112., 94., 93., 93., 90., 99., 93.,
	85., 89., 96., 111., 107., 114., 101., 108., 112., 105., 103., 99.,
	102., 110., 102., 96., 95., 112., 110., 92., 104., 75., 92., 92., 92.,
	93., 112., 88., 114., 103., 300., 303., 125., 280., 216., 190., 151.,
	303., 173., 203., 195., 140., 151., 275., 260., 149., 233., 146., 124.,
	213., 330., 123., 130., 120., 138., 188., 339., 265., 353., 180., 213.,
	328., 346.)
, "insulin" = c(356., 289., 319., 356., 323., 381., 350., 301., 379., 296., 353., 306., 290.,
	371., 312., 393., 364., 359., 296., 345., 378., 304., 347., 327., 386.,
	365., 365., 352., 325., 321., 360., 336., 352., 353., 373., 376., 367.,
	335., 396., 277., 378., 360., 291., 269., 318., 328., 334., 356., 291.,
	360., 313., 306., 319., 349., 332., 323., 323., 351., 478., 398., 426.,
	439., 429., 333., 472., 436., 418., 391., 390., 416., 413., 385., 393.,
	376., 403., 414., 426., 364., 391., 356., 398., 393., 425., 318., 465.,
	558., 503., 540., 469., 486., 568., 527., 537., 466., 599., 477., 472.,
	456., 517., 503., 522., 476., 472., 45., 442., 541., 580., 472., 562.,
	423., 643., 533., 1468., 1487., 714., 1470., 1113., 972., 854., 1364.,
	832., 967., 920., 613., 857., 1373., 1133., 849., 1183., 847., 538.,
	1001., 1520., 557., 670., 636., 741., 958., 1354., 1263., 1428., 923.,
	1025., 1246., 1568.)
, "sspg" = c(124., 117., 143., 199., 240., 157., 221., 186., 142., 131., 221., 178., 136.,
	200., 208., 202., 152., 185., 116., 123., 136., 134., 184., 192., 279.,
	228., 145., 172., 179., 222., 134., 143., 169., 263., 174., 134., 182.,
	241., 128., 222., 165., 282., 94., 121., 73., 106., 118., 112., 157.,
	292., 200., 220., 144., 109., 151., 158., 73., 81., 151., 122., 117.,
	208., 201., 131., 162., 148., 130., 137., 375., 146., 344., 192., 115.,
	195., 267., 281., 213., 156., 221., 199., 76., 490., 143., 73., 237.,
	748., 320., 188., 607., 297., 232., 480., 622., 287., 266., 124., 297.,
	326., 564., 408., 325., 433., 180., 392., 109., 313., 132., 285., 139.,
	212., 155., 120., 28., 23., 232., 54., 81., 87., 76., 42., 102., 138.,
	160., 131., 145., 45., 118., 159., 73., 103., 460., 42., 13., 130.,
	44., 314., 219., 100., 10., 83., 41., 77., 29., 124., 15.)
)
, class = "data.frame"
, names = c("class", "glucose", "insulin", "sspg")
, row.names = c("1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14",
	"15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26",
	"27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38",
	"39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50",
	"51", "52", "53", "54", "55", "56", "57", "58", "59", "60", "61", "62",
	"63", "64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74",
	"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86",
	"87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", "98",
	"99", "100", "101", "102", "103", "104", "105", "106", "107", "108",
	"109", "110", "111", "112", "113", "114", "115", "116", "117", "118",
	"119", "120", "121", "122", "123", "124", "125", "126", "127", "128",
	"129", "130", "131", "132", "133", "134", "135", "136", "137", "138",
	"139", "140", "141", "142", "143", "144", "145")
)

==> mclust_6.1.1.tar.gz: mclust/data/diabetes.R <==
diabetes <- 
structure(.Data = list(
  "class" = structure(.Data = c(2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 2, 1, 1, 2, 2, 2, 2, 1,
	2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3), 
  class = "factor", levels = c("Chemical", "Normal", "Overt")),
  "glucose" = c(80., 97., 105., 90., 90., 86., 100., 85., 97., 97., 91., 
  87., 78., 90., 86.,
	80., 90., 99., 85., 90., 90., 88., 95., 90., 92., 74., 98., 100., 86.,
	98., 70., 99., 75., 90., 85., 99., 100., 78., 106., 98., 102., 90.,
	94., 80., 93., 86., 85., 96., 88., 87., 94., 93., 86., 86., 96., 86.,
	89., 83., 98., 100., 110., 88., 100., 80., 89., 91., 96., 95., 82.,
	84., 90., 100., 86., 93., 107., 112., 94., 93., 93., 90., 99., 93.,
	85., 89., 96., 111., 107., 114., 101., 108., 112., 105., 103., 99.,
	102., 110., 102., 96., 95., 112., 110., 92., 104., 75., 92., 92., 92.,
	93., 112., 88., 114., 103., 300., 303., 125., 280., 216., 190., 151.,
	303., 173., 203., 195., 140., 151., 275., 260., 149., 233., 146., 124.,
	213., 330., 123., 130., 120., 138., 188., 339., 265., 353., 180., 213.,
	328., 346.), 
  "insulin" = c(356., 289., 319., 356., 323., 381., 350., 301., 379., 296., 
  353., 306., 290.,
	371., 312., 393., 364., 359., 296., 345., 378., 304., 347., 327., 386.,
	365., 365., 352., 325., 321., 360., 336., 352., 353., 373., 376., 367.,
	335., 396., 277., 378., 360., 291., 269., 318., 328., 334., 356., 291.,
	360., 313., 306., 319., 349., 332., 323., 323., 351., 478., 398., 426.,
	439., 429., 333., 472., 436., 418., 391., 390., 416., 413., 385., 393.,
	376., 403., 414., 426., 364., 391., 356., 398., 393., 425., 318., 465.,
	558., 503., 540., 469., 486., 568., 527., 537., 466., 599., 477., 472.,
	456., 517., 503., 522., 476., 472., 45., 442., 541., 580., 472., 562.,
	423., 643., 533., 1468., 1487., 714., 1470., 1113., 972., 854., 1364.,
	832., 967., 920., 613., 857., 1373., 1133., 849., 1183., 847., 538.,
	1001., 1520., 557., 670., 636., 741., 958., 1354., 1263., 1428., 923.,
	1025., 1246., 1568.), 
  "sspg" = c(124., 117., 143., 199., 240., 157., 221., 186., 142., 131., 
  221., 178., 136.,
	200., 208., 202., 152., 185., 116., 123., 136., 134., 184., 192., 279.,
	228., 145., 172., 179., 222., 134., 143., 169., 263., 174., 134., 182.,
	241., 128., 222., 165., 282., 94., 121., 73., 106., 118., 112., 157.,
	292., 200., 220., 144., 109., 151., 158., 73., 81., 151., 122., 117.,
	208., 201., 131., 162., 148., 130., 137., 375., 146., 344., 192., 115.,
	195., 267., 281., 213., 156., 221., 199., 76., 490., 143., 73., 237.,
	748., 320., 188., 607., 297., 232., 480., 622., 287., 266., 124., 297.,
	326., 564., 408., 325., 433., 180., 392., 109., 313., 132., 285., 139.,
	212., 155., 120., 28., 23., 232., 54., 81., 87., 76., 42., 102., 138.,
	160., 131., 145., 45., 118., 159., 73., 103., 460., 42., 13., 130.,
	44., 314., 219., 100., 10., 83., 41., 77., 29., 124., 15.)
), 
  class = "data.frame",
  names = c("class", "glucose", "insulin", "sspg"),
  row.names = c(
  "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14",
	"15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26",
	"27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38",
	"39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50",
	"51", "52", "53", "54", "55", "56", "57", "58", "59", "60", "61", "62",
	"63", "64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74",
	"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86",
	"87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", "98",
	"99", "100", "101", "102", "103", "104", "105", "106", "107", "108",
	"109", "110", "111", "112", "113", "114", "115", "116", "117", "118",
	"119", "120", "121", "122", "123", "124", "125", "126", "127", "128",
	"129", "130", "131", "132", "133", "134", "135", "136", "137", "138",
	"139", "140", "141", "142", "143", "144", "145")
)
